Documentation
¶
Overview ¶
Package smpeer provides functions for extracting information from a CER or CEA, and associating with a Context.
Example:
func handleXYZ(c diam.Conn, m *diam.Message) {
meta, ok := smpeer.FromContext(c.Context())
if ok {
log.Println(meta)
}
}
See the Metadata type for details.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Metadata ¶
type Metadata struct {
OriginHost datatype.DiameterIdentity
OriginRealm datatype.DiameterIdentity
Applications []uint32 // Acct or Auth IDs supported by the peer.
}
Metadata contains information about a diameter peer, acquired during the CER/CEA handshake.
Click to show internal directories.
Click to hide internal directories.